=== modified file 'bootstrap.sh'
--- bootstrap.sh	2013-01-07 05:33:02 +0000
+++ bootstrap.sh	2013-01-10 12:04:23 +0000
@@ -45,8 +45,24 @@
 
 command_not_found_handle ()
 {
-  echo "Command not found: '$@'"
-  exit 127
+  warn "$@: command not found"
+
+  #if $DEBUG; then 
+    echo ""
+    echo "Stack trace:"
+    local frame=0
+    while caller $frame; do
+      ((frame++));
+    done
+    echo ""
+  #fi
+
+  return 127
+}
+
+function error ()
+{ 
+  echo "$BASH_SOURCE:$BASH_LINENO: $@" >&2
 }
 
 function die ()
@@ -55,6 +71,12 @@
   exit 1; 
 }
 
+function warn ()
+{ 
+  echo "$BASH_SOURCE:$BASH_LINENO: $@"
+  #echo "$BASH_SOURCE:$BASH_LINENO: $@" >&1
+}
+
 function nassert ()
 {
   local param_name=\$"$1"
@@ -77,7 +99,7 @@
   fi
 }
 
-assert_file ()
+function assert_file ()
 {
   if [ ! -f "$1" ]; then
     echo "$BASH_SOURCE:$BASH_LINENO: assert($1) does not exist: $2" >&2
@@ -85,7 +107,7 @@
   fi
 }
 
-assert_no_file ()
+function assert_no_file ()
 {
   if [ -f "$1" ]; then
     echo "$BASH_SOURCE:$BASH_LINENO: assert($1) file exists: $2" >&2
@@ -93,7 +115,7 @@
   fi
 }
 
-assert_no_directory ()
+function assert_no_directory ()
 {
   if [ -d "$1" ]; then
     echo "$BASH_SOURCE:$BASH_LINENO: assert($1) directory exists: $2" >&2
@@ -101,7 +123,7 @@
   fi
 }
 
-assert_exec_file ()
+function assert_exec_file ()
 {
   if [ ! -f "$1" ]; then
     echo "$BASH_SOURCE:$BASH_LINENO: assert($1) does not exist: $2" >&2
@@ -114,20 +136,12 @@
   fi
 }
 
-command_exists ()
+function command_exists ()
 {
-  # ret=0
-  # $1 --version >/dev/null 2>&1
-  #if [ 126 -le $? ]; then
-  #echo "$me: Error: '$app' not found" >&2
-  #ret=1
-  #fi
-  #return $ret
-
   type "$1" &> /dev/null ;
 }
 
-rebuild_host_os ()
+function rebuild_host_os ()
 {
   HOST_OS="${UNAME_MACHINE_ARCH}-${VENDOR}-${VENDOR_DISTRIBUTION}-${VENDOR_RELEASE}-${UNAME_KERNEL}-${UNAME_KERNEL_RELEASE}"
   if [ -z "$1" ]; then
@@ -138,7 +152,7 @@
 }
 
 #  Valid values are: darwin,fedora,rhel,ubuntu
-set_VENDOR_DISTRIBUTION ()
+function set_VENDOR_DISTRIBUTION ()
 {
   local dist=`echo "$1" | tr '[A-Z]' '[a-z]'`
   case "$dist" in
@@ -163,7 +177,7 @@
   esac
 }
 
-set_VENDOR_RELEASE ()
+function set_VENDOR_RELEASE ()
 {
   local release=`echo "$1" | tr '[A-Z]' '[a-z]'`
   case "$VENDOR_DISTRIBUTION" in
@@ -193,7 +207,7 @@
 
 
 #  Valid values are: apple, redhat, centos, canonical
-set_VENDOR ()
+function set_VENDOR ()
 {
   local vendor=`echo "$1" | tr '[A-Z]' '[a-z]'`
 
@@ -222,7 +236,7 @@
   set_VENDOR_RELEASE $3
 }
 
-determine_target_platform ()
+function determine_target_platform ()
 {
   UNAME_MACHINE_ARCH=`(uname -m) 2>/dev/null` || UNAME_MACHINE_ARCH=unknown
   UNAME_KERNEL=`(uname -s) 2>/dev/null`  || UNAME_SYSTEM=unknown
@@ -258,7 +272,7 @@
   rebuild_host_os
 }
 
-run_configure ()
+function run_configure ()
 {
   # We will run autoreconf if we are required
   run_autoreconf_if_required
@@ -268,6 +282,10 @@
     die "Programmer error, we entered run_configure with a stacked directory"
   fi
 
+  if ! command_exists "$CONFIGURE"; then
+    die "$CONFIGURE does not exist"
+  fi
+
   local BUILD_DIR="$1"
   if [[ -n "$BUILD_DIR" ]]; then
     rm -r -f $BUILD_DIR
@@ -276,40 +294,52 @@
   fi
 
   # Arguments for configure
-  local CONFIGURE_ARG= 
+  local BUILD_CONFIGURE_ARG= 
 
   # Set ENV DEBUG in order to enable debugging
   if $DEBUG; then 
-    CONFIGURE_ARG='--enable-debug'
+    BUILD_CONFIGURE_ARG='--enable-debug'
   fi
 
   # Set ENV ASSERT in order to enable assert
   if [[ -n "$ASSERT" ]]; then 
     local ASSERT_ARG=
     ASSERT_ARG='--enable-assert'
-    CONFIGURE_ARG="$ASSERT_ARG $CONFIGURE_ARG"
-  fi
-
+    BUILD_CONFIGURE_ARG="$ASSERT_ARG $BUILD_CONFIGURE_ARG"
+  fi
+
+  if [[ -n "$CONFIGURE_ARG" ]]; then 
+    BUILD_CONFIGURE_ARG= "$BUILD_CONFIGURE_ARG $CONFIGURE_ARG"
+  fi
+
+  ret=1;
   # If we are executing on OSX use CLANG, otherwise only use it if we find it in the ENV
   case $HOST_OS in
     *-darwin-*)
-      CC=clang CXX=clang++ $top_srcdir/configure $CONFIGURE_ARG || die "Cannot execute CC=clang CXX=clang++ configure $CONFIGURE_ARG $PREFIX_ARG"
+      CC=clang CXX=clang++ $top_srcdir/configure $BUILD_CONFIGURE_ARG || die "Cannot execute CC=clang CXX=clang++ configure $BUILD_CONFIGURE_ARG $PREFIX_ARG"
+      ret=$?
       ;;
     rhel-5*)
-      command_exists gcc44 || die "Could not locate gcc44"
-      CC=gcc44 CXX=gcc44 $top_srcdir/configure $CONFIGURE_ARG $PREFIX_ARG || die "Cannot execute CC=gcc44 CXX=gcc44 configure $CONFIGURE_ARG $PREFIX_ARG"
+      command_exists 'gcc44' || die "Could not locate gcc44"
+      CC=gcc44 CXX=gcc44 $top_srcdir/configure $BUILD_CONFIGURE_ARG $PREFIX_ARG || die "Cannot execute CC=gcc44 CXX=gcc44 configure $BUILD_CONFIGURE_ARG $PREFIX_ARG"
+      ret=$?
       ;;
     *)
-      $top_srcdir/configure $CONFIGURE_ARG $PREFIX_ARG || die "Cannot execute configure $CONFIGURE_ARG $PREFIX_ARG"
+      $CONFIGURE $BUILD_CONFIGURE_ARG $PREFIX_ARG
+      ret=$?
       ;;
   esac
 
+  if [ $ret -ne 0 ]; then
+    die "Could not execute $CONFIGURE $BUILD_CONFIGURE_ARG $PREFIX_ARG"
+  fi
+
   if [ ! -f 'Makefile' ]; then
-    die "Programmer error, configure was run but no Makefile existed afterward"
+    die "Programmer error, configure was run but no Makefile existed after $CONFIGURE was run"
   fi
 }
 
-setup_gdb_command () {
+function setup_gdb_command () {
   GDB_TMPFILE=$(mktemp /tmp/gdb.XXXXXXXXXX)
   echo 'set logging overwrite on' > $GDB_TMPFILE
   echo 'set logging on' >> $GDB_TMPFILE
@@ -320,15 +350,79 @@
   GDB_COMMAND="gdb -f -batch -x $GDB_TMPFILE"
 }
 
-setup_valgrind_command () {
+function setup_valgrind_command () {
   VALGRIND_PROGRAM=`type -p valgrind`
   if [[ -n "$VALGRIND_PROGRAM" ]]; then
     VALGRIND_COMMAND="$VALGRIND_PROGRAM --error-exitcode=1 --leak-check=yes --show-reachable=yes --track-fds=yes --malloc-fill=A5 --free-fill=DE"
   fi
 }
 
-push_PREFIX_ARG ()
-{
+function save_BUILD ()
+{
+  if [[ -n "$OLD_CONFIGURE" ]]; then
+    die "OLD_CONFIGURE($OLD_CONFIGURE) was set on push, programmer error!"
+  fi
+
+  if [[ -n "$OLD_CONFIGURE_ARG" ]]; then
+    die "OLD_CONFIGURE_ARG($OLD_CONFIGURE_ARG) was set on push, programmer error!"
+  fi
+
+  if [[ -n "$OLD_MAKE" ]]; then
+    die "OLD_MAKE($OLD_MAKE) was set on push, programmer error!"
+  fi
+
+  if [[ -n "$OLD_TESTS_ENVIRONMENT" ]]; then
+    die "OLD_TESTS_ENVIRONMENT($OLD_TESTS_ENVIRONMENT) was set on push, programmer error!"
+  fi
+
+  if [[ -n "$CONFIGURE" ]]; then
+    OLD_CONFIGURE=$CONFIGURE
+  fi
+
+  if [[ -n "$CONFIGURE_ARG" ]]; then
+    OLD_CONFIGURE_ARG=$CONFIGURE_ARG
+  fi
+
+  if [[ -n "$MAKE" ]]; then
+    OLD_MAKE=$MAKE
+  fi
+
+  if [[ -n "$TESTS_ENVIRONMENT" ]]; then
+    OLD_TESTS_ENVIRONMENT=$TESTS_ENVIRONMENT
+  fi
+}
+
+function restore_BUILD ()
+{
+  if [[ -n "$OLD_CONFIGURE" ]]; then
+    CONFIGURE=$OLD_CONFIGURE
+  fi
+
+  if [[ -n "$OLD_CONFIGURE_ARG" ]]; then
+    CONFIGURE_ARG=$OLD_CONFIGURE_ARG
+  fi
+
+  if [[ -n "$OLD_MAKE" ]]; then
+    MAKE=$OLD_MAKE
+  fi
+
+  if [[ -n "$OLD_TESTS_ENVIRONMENT" ]]; then
+    TESTS_ENVIRONMENT=$OLD_TESTS_ENVIRONMENT
+  fi
+
+  OLD_CONFIGURE=
+  OLD_CONFIGURE_ARG=
+  OLD_MAKE=
+  OLD_TESTS_ENVIRONMENT=
+  echo "reset happened"
+}
+
+function push_PREFIX_ARG ()
+{
+  if [[ -n "$OLD_PREFIX_ARG" ]]; then
+    die "OLD_PREFIX_ARG was set on push, programmer error!"
+  fi
+
   if [[ -n "$PREFIX_ARG" ]]; then
     OLD_PREFIX_ARG=$PREFIX_ARG
     PREFIX_ARG=
@@ -339,17 +433,17 @@
   fi
 }
 
-pop_PREFIX_ARG ()
+function pop_PREFIX_ARG ()
 {
   if [[ -n "$OLD_PREFIX_ARG" ]]; then
-    PREFIX_ARG=$OLD_TESTS_ENVIRONMENT
+    PREFIX_ARG=$OLD_PREFIX_ARG
     OLD_PREFIX_ARG=
   else
     PREFIX_ARG=
   fi
 }
 
-push_TESTS_ENVIRONMENT ()
+function push_TESTS_ENVIRONMENT ()
 {
   if [[ -n "$OLD_TESTS_ENVIRONMENT" ]]; then
     die "OLD_TESTS_ENVIRONMENT was set on push, programmer error!"
@@ -361,7 +455,7 @@
   fi
 }
 
-pop_TESTS_ENVIRONMENT ()
+function pop_TESTS_ENVIRONMENT ()
 {
   TESTS_ENVIRONMENT=
   if [[ -n "$OLD_TESTS_ENVIRONMENT" ]]; then
@@ -514,14 +608,63 @@
   snapshot_check
 }
 
-function make_for_mingw32 ()
-{
-  if ! command_exists mingw32-configure; then
-    die 'mingw32-configure was not found, do you have mingw installed?'
-  fi
-
-  if ! command_exists mingw32-make; then
-    die 'mingw32-make was not found, do you have mingw installed?'
+function check_mingw ()
+{
+  command_exists 'mingw64-configure'
+  ret=$?
+  if [ "$ret" -ne 0 ]; then
+    return 1
+  fi
+
+  command_exists 'mingw64-make'
+  ret=$?
+  if [ "$ret" -ne 0 ]; then
+    return 1
+  fi
+
+  return 0
+}
+
+function make_skeleton_mingw ()
+{
+  run_configure
+  ret=$?
+
+  if [ $ret -eq 0 ]; then
+    assert_file 'Makefile'
+
+    make_target 'all' 'warn'
+    ret=$?
+    if [ $ret -ne 0 ]; then
+      warn "$MAKE failed"
+    else
+      if [[ -n "$DISPLAY" ]]; then
+        if command_exists 'wine'; then
+          TESTS_ENVIRONMENT='wine'
+        fi
+      elif command_exists 'wineconsole'; then
+        TESTS_ENVIRONMENT='wineconsole --backend=curses'
+      fi
+
+      if [[ -n "$TESTS_ENVIRONMENT" ]]; then
+        make_target 'check' 'warn' || warn "$MAKE check failed"
+        ret=$?
+      fi
+    fi
+
+    if $jenkins_build_environment; then
+      make_target 'clean' 'warn'
+    fi
+  fi
+
+  return $ret
+}
+
+function make_for_mingw ()
+{
+  check_mingw
+  if ! check_mingw; then
+    die 'mingw64 tools were not found'
   fi
 
   # Make sure it is clean
@@ -531,14 +674,18 @@
 
   run_autoreconf
 
-  mingw32-configure '--enable-static' || die 'mingw32-configure failed'
-  assert_file 'Makefile'
-
-  mingw32-make || die 'mingw32-make failed'
-  if command_exists wineconsole; then
-    TESTS_ENVIRONMENT='wineconsole --backend=curses'
-    mingw32-make 'check' || die 'mingw32-make check failed'
-  fi
+  save_BUILD
+
+  CONFIGURE='mingw64-configure'
+  MAKE='mingw64-make'
+  CONFIGURE_ARGS='--enable-static'
+
+  make_skeleton_mingw
+  ret=$?
+
+  restore_BUILD
+
+  return $ret
 }
 
 # If we are locally testing, we should make sure the environment is setup correctly
@@ -563,7 +710,11 @@
   make_valgrind
   make_gdb
   make_rpm
-  make_for_mingw32
+
+  if [ check_mingw -eq 0 ]; then
+    make_for_mingw
+  fi
+
   make_distcheck
   make_install_system
 }
@@ -664,9 +815,8 @@
 
 function make_gdb ()
 {
-  run_configure_if_required
-
-  if command_exists gdb; then
+  if command_exists 'gdb'; then
+    run_configure_if_required
 
     push_TESTS_ENVIRONMENT
 
@@ -683,7 +833,7 @@
       TESTS_ENVIRONMENT="$GDB_COMMAND"
     fi
 
-    make_target check
+    make_target 'check'
 
     if [ -f 'gdb.txt' ]; then
       rm 'gdb.txt'
@@ -694,6 +844,10 @@
     if [ -f '.gdb_history' ]; then
       rm '.gdb_history'
     fi
+
+    if $jenkins_build_environment; then
+      make_target 'clean'
+    fi
   else
     echo 'gdb was not present'
     return 1
@@ -723,11 +877,19 @@
     die "MAKE was not set"
   fi
 
-  if [ -n "$2" ]; then
-    run $MAKE $1 || return 1
-  else
-    run $MAKE $1 || die "Cannot execute $MAKE $1"
+  # $2 represents error or warn
+  run $MAKE $1
+  ret=$?
+
+  if [ $ret -ne 0 ]; then
+    if [ -n "$2" ]; then
+      warn "Cannot execute $MAKE $1: $ret"
+    else
+      die "Cannot execute $MAKE $1: $ret"
+    fi
   fi
+
+  return $ret
 }
 
 function make_distcheck ()
@@ -737,9 +899,16 @@
 
 function make_rpm ()
 {
-  if [ -f 'rpm.am' -o -d 'rpm' ]; then
-    run_configure_if_required
-    make_target 'rpm'
+  if command_exists 'rpmbuild'; then
+    if [ -f 'rpm.am' -o -d 'rpm' ]; then
+      run_configure_if_required
+      make_target 'rpm'
+
+      if $jenkins_build_environment; then
+        make_target 'clean'
+      fi
+
+    fi
   fi
 }
 
@@ -813,10 +982,14 @@
     echo "\`$@' $ARGS"
   fi
 
+  if [ -z "$1" ]; then
+    return 127;
+  fi
+
   eval $@ $ARGS
 } 
 
-parse_command_line_options ()
+function parse_command_line_options ()
 {
   local SHORTOPTS=':apcmt:dvh'
 
@@ -874,7 +1047,7 @@
   fi
 }
 
-determine_vcs ()
+function determine_vcs ()
 {
   if [[ -d '.git' ]]; then
     VCS_CHECKOUT=git
@@ -904,10 +1077,10 @@
 {
   # Set ENV MAKE in order to override "make"
   if [[ -z "$MAKE" ]]; then 
-    if command_exists gmake; then
+    if command_exists 'gmake'; then
       MAKE=`type -p gmake`
     else
-      if command_exists make; then
+      if command_exists 'make'; then
         MAKE=`type -p make`
       fi
     fi
@@ -1016,7 +1189,7 @@
   run $AUTORECONF '--help'  &> /dev/null    || die "Failed to run AUTORECONF:$AUTORECONF"
 }
 
-print_setup ()
+function print_setup ()
 {
   saved_debug_status=$DEBUG
   if $DEBUG; then
@@ -1095,7 +1268,7 @@
   fi
 }
 
-make_clean_option ()
+function make_clean_option ()
 {
   run_configure_if_required
 
@@ -1108,7 +1281,7 @@
   fi
 }
 
-make_for_autoreconf ()
+function make_for_autoreconf ()
 {
   if [ -f 'Makefile' ]; then
     make_maintainer_clean
@@ -1119,7 +1292,7 @@
   assert_no_file 'Makefile'
 }
 
-check_make_target()
+function check_make_target()
 {
   case $1 in
     'self')
@@ -1245,7 +1418,17 @@
         make_default
         ;;
       'mingw')
-        make_for_mingw32
+        check_mingw
+        if ! check_mingw; then
+          die "mingw was not found"
+        fi
+
+        make_for_mingw
+        check_ret=$?
+
+        if ! make_for_mingw; then
+          die "Failed to build mingw: $?"
+        fi
         ;;
       'snapshot')
         make_for_snapshot
@@ -1270,13 +1453,14 @@
   done
 }
 
-main ()
+function main ()
 {
   # Variables we export
   declare -x VCS_CHECKOUT=
 
   # Variables we control globally
   local MAKE_TARGET=
+  local CONFIGURE=
 
   # Options for getopt
   local AUTORECONF_OPTION=false
@@ -1288,12 +1472,23 @@
   local TARGET_OPTION_ARG=
   local VERBOSE_OPTION=false
 
+  local OLD_CONFIGURE=
+  local OLD_CONFIGURE_ARG=
+  local OLD_MAKE=
+  local OLD_TESTS_ENVIRONMENT=
+
   # If we call autoreconf on the platform or not
   local AUTORECONF_REBUILD_HOST=false
   local AUTORECONF_REBUILD=false
 
   local -r top_srcdir=`pwd`
 
+  # Default configure
+  if [ -z "$CONFIGURE" ]; then
+    CONFIGURE="$top_srcdir/configure"
+  fi
+
+
   # Variables for determine_target_platform () and rebuild_host_os ()
   #   UNAME_MACHINE_ARCH= uname -m
   #   VENDOR= apple, redhat, centos, canonical
@@ -1376,7 +1571,7 @@
   fi
 }
 
-enable_debug ()
+function enable_debug ()
 {
   if ! $DEBUG; then
     local caller_loc=`caller`
@@ -1402,7 +1597,7 @@
 EOF
 }
 
-disable_debug ()
+function disable_debug ()
 {
   set +x
   DEBUG=true

=== modified file 'configure.ac'
--- configure.ac	2013-01-08 12:12:01 +0000
+++ configure.ac	2013-01-10 12:04:23 +0000
@@ -58,7 +58,7 @@
 # Checks for libraries.
 AX_CXX_GCC_ABI_DEMANGLE
 
-AS_IF([test "x${target_os}" != "xmingw32"], [AX_CHECK_OPENSSL])
+AS_IF([test "x${TARGET_WINDOWS}" != "xtrue"],[AX_CHECK_OPENSSL])
 
 AC_PATH_ZLIB
 

=== modified file 'libdrizzle/common.h'
--- libdrizzle/common.h	2013-01-05 15:46:05 +0000
+++ libdrizzle/common.h	2013-01-10 12:04:23 +0000
@@ -49,7 +49,7 @@
 # include <fcntl.h>
 #endif
 
-#if defined(WIN32) || defined(__MINGW32__)
+#if defined(_WIN32) || defined(__MINGW32__)
 # include "libdrizzle/windows.hpp"
 # define get_socket_errno() WSAGetLastError()
 
@@ -63,7 +63,7 @@
 # define closesocket(a) close(a)
 # define get_socket_errno() errno
 
-#endif // defined(WIN32) || defined(__MINGW32__)
+#endif // defined(_WIN32) || defined(__MINGW32__)
 
 #if defined(HAVE_POLL_H) && HAVE_POLL_H
 # include <poll.h>

=== modified file 'm4/ax_check_library.m4'
--- m4/ax_check_library.m4	2012-12-17 11:57:49 +0000
+++ m4/ax_check_library.m4	2013-01-10 12:04:23 +0000
@@ -61,7 +61,7 @@
 #   modified version of the Autoconf Macro, you may extend this special
 #   exception to the GPL to apply to your modified version as well.
 
-#serial 6
+#serial 7
 
 AC_DEFUN([AX_CHECK_LIBRARY],
     [AC_ARG_VAR($1[_CPPFLAGS],[C preprocessor flags for ]$1[ headers])
@@ -92,5 +92,4 @@
         AC_SUBST($1[_LIB],[-l]$3)
         ifelse([$4], , :, [$4])],
         [ifelse([$5], , :, [$5])])
-    AM_CONDITIONAL([HAVE_]$1,[test "$]AS_TR_SH([ax_cv_have_]$1)[" = "yes"])
     ])

=== modified file 'm4/ax_cxx_gcc_abi_demangle.m4'
--- m4/ax_cxx_gcc_abi_demangle.m4	2012-12-17 11:57:49 +0000
+++ m4/ax_cxx_gcc_abi_demangle.m4	2013-01-10 12:04:23 +0000
@@ -24,7 +24,7 @@
 #   and this notice are preserved. This file is offered as-is, without any
 #   warranty.
 
-#serial 9
+#serial 10
 
 AC_DEFUN([AX_CXX_GCC_ABI_DEMANGLE],
     [AC_PREREQ([2.63])dnl
@@ -38,6 +38,9 @@
           template<typename TYPE>
           class A {};]],
           [[A<int> instance;
+#if defined(_WIN32) 
+          return EXIT_FAILURE; 
+#endif
           int status = 0;
           char* c_name = abi::__cxa_demangle(typeid(instance).name(), 0, 0, &status);
 
@@ -52,6 +55,8 @@
         [ax_cv_cxx_gcc_abi_demangle=no],
         [ax_cv_cxx_gcc_abi_demangle=no])
       AC_LANG_POP])
+      AC_MSG_CHECKING([checking for cxx_gcc_abi_demangle])
+  AC_MSG_RESULT(["$ax_cv_cxx_gcc_abi_demangle"])
   AS_IF([test "x$ax_cv_cxx_gcc_abi_demangle" = xyes],
       [AC_DEFINE([HAVE_GCC_ABI_DEMANGLE],[1],[define if the compiler supports GCC C++ ABI name demangling])])
   ])

=== modified file 'm4/ax_debug.m4'
--- m4/ax_debug.m4	2012-12-17 11:57:49 +0000
+++ m4/ax_debug.m4	2013-01-10 12:04:23 +0000
@@ -43,7 +43,7 @@
 #  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 #  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#serial 4
+#serial 5
 
 AC_DEFUN([AX_DEBUG],
     [AC_PREREQ([2.63])dnl
@@ -51,10 +51,12 @@
       [AS_HELP_STRING([--enable-debug],
         [Add debug code/turns off optimizations (yes|no) @<:@default=no@:>@])],
       [ax_enable_debug=yes
-      AC_DEFINE(DEBUG,[1],[Define to 1 to enable debugging code.])],
+      AC_DEFINE([DEBUG],[1],[Define to 1 to enable debugging code.])
+      AX_CHECK_LIBRARY([MCHECK],[mcheck.h],[mcheck],[AX_APPEND_LINK_FLAGS([-lmcheck])])],
       [ax_enable_debug=no
-      AC_DEFINE(DEBUG, [ 0 ], [Define to 1 to enable debugging code.])])
+      AC_SUBST([MCHECK])
+      AC_DEFINE([DEBUG],[0],[Define to 1 to enable debugging code.])])
 
     AC_MSG_CHECKING([for debug])
     AC_MSG_RESULT([$ax_enable_debug])
-    ])
+    AM_CONDITIONAL([DEBUG],[test "x${ax_enable_debug}" = "xyes"])])

=== modified file 'm4/ax_dlopen.m4'
--- m4/ax_dlopen.m4	2012-12-17 11:57:49 +0000
+++ m4/ax_dlopen.m4	2013-01-10 12:04:23 +0000
@@ -1,11 +1,10 @@
-#serial 1
+#serial 2
 
 AC_DEFUN([AX_DLOPEN],
-         [AS_IF([test "x$enable_shared" = xyes],
-                [AX_CHECK_LIBRARY([DL],[dlfcn.h],[dl],
-                                  [AC_DEFINE([HAVE_LIBDL],[1],[Have dlopen])
-                                  AC_CHECK_LIB([dl],[dlopen],[AC_DEFINE([HAVE_DLOPEN],[1],[Have dlopen])])
-                                  AC_CHECK_LIB([dl],[dladdr],[AC_DEFINE([HAVE_DLADDR],[1],[Have dladdr])])])],
-                [AM_CONDITIONAL([HAVE_DL],false)])
-         ])
+    [AS_IF([test "x$enable_shared" = xyes],
+      [AX_CHECK_LIBRARY([DL],[dlfcn.h],[dl],
+        [AC_DEFINE([HAVE_LIBDL],[1],[Have dlopen])
+        AC_CHECK_LIB([dl],[dlopen],[AC_DEFINE([HAVE_DLOPEN],[1],[Have dlopen])])
+        AC_CHECK_LIB([dl],[dladdr],[AC_DEFINE([HAVE_DLADDR],[1],[Have dladdr])])])])
+    ])
 

=== modified file 'm4/ax_harden_compiler_flags.m4'
--- m4/ax_harden_compiler_flags.m4	2013-01-07 05:33:02 +0000
+++ m4/ax_harden_compiler_flags.m4	2013-01-10 12:04:23 +0000
@@ -61,9 +61,10 @@
       ])
     ])
 
+# Note: Should this be LIBS or LDFLAGS?
 AC_DEFUN([_APPEND_LINK_FLAGS_ERROR],
          [AC_REQUIRE([AX_APPEND_LINK_FLAGS])
-         AX_APPEND_LINK_FLAGS([$1],[LIB],[-Werror])
+         AX_APPEND_LINK_FLAGS([$1],[LDFLAGS],[-Werror])
          ])
 
 AC_DEFUN([_APPEND_COMPILE_FLAGS_ERROR],
@@ -75,7 +76,7 @@
 
 AC_DEFUN([_HARDEN_LINKER_FLAGS],
          [_APPEND_LINK_FLAGS_ERROR([-z relro -z now])
-         _APPEND_LINK_FLAGS_ERROR([-pie])
+         #_APPEND_LINK_FLAGS_ERROR([-pie])
          AS_IF([test "x$ac_cv_warnings_as_errors" = xyes],
                [AX_APPEND_LINK_FLAGS([-Werror])])
          ])
@@ -151,7 +152,7 @@
 
           AS_IF([test "x$ax_enable_debug" = xno],
             [AS_IF([test "x$ac_cv_vcs_checkout" = xyes],
-              [AS_IF([test "x${target_os}" != "xmingw32"],
+              [AS_IF([test "x${target_os}" != "xmingw"],
                 [AS_IF([test "x$ac_c_gcc_recent" = xyes],
                   [_APPEND_COMPILE_FLAGS_ERROR([-D_FORTIFY_SOURCE=2])
                   #_APPEND_COMPILE_FLAGS_ERROR([-Wstack-protector])
@@ -230,7 +231,7 @@
 
           AS_IF([test "x$ax_enable_debug" = xno],
           [AS_IF([test "x$ac_cv_vcs_checkout" = xyes],
-            [AS_IF([test "x${target_os}" != "xmingw32"],
+            [AS_IF([test "x${target_os}" != "xmingw"],
               [AS_IF([test "x$ac_c_gcc_recent" = xyes],
                 [_APPEND_COMPILE_FLAGS_ERROR([-D_FORTIFY_SOURCE=2])
                 #_APPEND_COMPILE_FLAGS_ERROR([-Wstack-protector])

=== modified file 'm4/ax_platform.m4'
--- m4/ax_platform.m4	2013-01-05 15:46:05 +0000
+++ m4/ax_platform.m4	2013-01-10 12:04:23 +0000
@@ -34,7 +34,7 @@
       AC_DEFINE_UNQUOTED([TARGET_CPU],["$target_cpu"], [CPU of Target System])
 
       AS_CASE([$target_os],
-        [*mingw32*],
+        [*mingw*],
         [TARGET_WINDOWS="true"
         AC_DEFINE([TARGET_OS_WINDOWS], [1], [Whether we are building for Windows])
         AC_DEFINE([EAI_SYSTEM], [11], [Another magical number])

=== modified file 'm4/ax_prog_sphinx_build.m4'
--- m4/ax_prog_sphinx_build.m4	2012-12-17 11:57:49 +0000
+++ m4/ax_prog_sphinx_build.m4	2013-01-10 12:04:23 +0000
@@ -39,7 +39,7 @@
         ])
       ])
 
-    AM_CONDITIONAL(HAVE_DPKG_GENSYMBOLS,[test "x${DPKG_GENSYMBOLS}" != "x:"])
-    AM_CONDITIONAL(HAVE_SPHINX,[test "x${SPHINXBUILD}" != "x:"])
-    AM_CONDITIONAL(HAVE_RECENT_SPHINX,[test "x${ac_cv_recent_sphinx}" = "xyes"])
+    AM_CONDITIONAL([HAVE_DPKG_GENSYMBOLS],[test "x${DPKG_GENSYMBOLS}" != "x:"])
+    AM_CONDITIONAL([HAVE_SPHINX],[test "x${SPHINXBUILD}" != "x:"])
+    AM_CONDITIONAL([HAVE_RECENT_SPHINX],[test "x${ac_cv_recent_sphinx}" = "xyes"])
 ])

